﻿using System;
using System.Windows;
using System.Windows.Ink;
using System.Windows.Media;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region Field

        /// <summary>
        /// 펜 색상 GUID
        /// </summary>
        private Guid penColorGUID = new Guid("12345678-9012-3456-7890-123456789012");

        /// <summary>
        /// 적색 펜 색상 드로잉 어트리뷰트
        /// </summary>
        private DrawingAttributes redPenColorDrawingAttributes = new DrawingAttributes();

        /// <summary>
        /// 청색 펜 색상 드로잉 어트리뷰트
        /// </summary>
        private DrawingAttributes bluePenColorDrawingAttributes = new DrawingAttributes();

        /// <summary>
        /// 적색 펜 색상 문자열
        /// </summary>
        private string redPenColorString = "redPenColor";

        /// <summary>
        /// 청색 펜 색상 문자열
        /// </summary>
        private string bluePenColorString = "bluePenColor";

        /// <summary>
        /// 청색 펜 색상 사용 여부
        /// </summary>
        private bool useBluePenColor = false;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            this.redPenColorDrawingAttributes.Color  = Colors.Red;
            this.redPenColorDrawingAttributes.Width  = 5;
            this.redPenColorDrawingAttributes.Height = 5;

            this.redPenColorDrawingAttributes.AddPropertyData(penColorGUID, redPenColorString);

            this.bluePenColorDrawingAttributes.Color  = Colors.Blue;
            this.bluePenColorDrawingAttributes.Width  = 5;
            this.bluePenColorDrawingAttributes.Height = 5;

            this.bluePenColorDrawingAttributes.AddPropertyData(penColorGUID, bluePenColorString);

            this.inkCanvas.DefaultDrawingAttributes = this.redPenColorDrawingAttributes;

            this.setPenColorButton.Click    += setPenColorButton_click;
            this.changePenColorButton.Click += changePenColorButton_click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 펜 색상 설정 버튼 클릭시 처리하기 - setPenColorButton_click(sender, e)

        /// <summary>
        /// 펜 색상 설정 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void setPenColorButton_click(object sender, RoutedEventArgs e)
        {
            this.useBluePenColor = !this.useBluePenColor;

            if(this.useBluePenColor)
            {
                this.setPenColorButton.Content = "적색 펜색 색상 사용";

                this.inkCanvas.DefaultDrawingAttributes = this.bluePenColorDrawingAttributes;
            }
            else
            {
                this.setPenColorButton.Content = "청색 펜색 색상 사용";

                this.inkCanvas.DefaultDrawingAttributes = this.redPenColorDrawingAttributes;
            }
        }

        #endregion
        #region 펜 색상 변경하기 버튼 클릭시 처리하기 - changePenColorButton_click(sender, e)

        /// <summary>
        /// 펜 색상 변경하기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void changePenColorButton_click(object sender, RoutedEventArgs e)
        {
            foreach(Stroke stroke in this.inkCanvas.Strokes)
            {
                if(stroke.DrawingAttributes.ContainsPropertyData(penColorGUID))
                {
                    object data = stroke.DrawingAttributes.GetPropertyData(penColorGUID);

                    if((data is string) && ((string)data == redPenColorString))
                    {
                        stroke.DrawingAttributes.Color = Colors.Black;
                    }

                    if((data is string) && ((string)data == bluePenColorString))
                    {
                        stroke.DrawingAttributes.Color = Colors.Green;
                    }
                }
            }
        }

        #endregion
    }
}